function varargout = referencefig(varargin)
% REFERENCEFIG MATLAB code for referencefig.fig
%      REFERENCEFIG, by itself, creates a new REFERENCEFIG or raises the existing
%      singleton*.
%
%      H = REFERENCEFIG returns the handle to a new REFERENCEFIG or the handle to
%      the existing singleton*.
%
%      REFERENCEFIG('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in REFERENCEFIG.M with the given input arguments.
%
%      REFERENCEFIG('Property','Value',...) creates a new REFERENCEFIG or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before referencefig_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to referencefig_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help referencefig

% Last Modified by GUIDE v2.5 23-Nov-2011 11:20:25

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @referencefig_OpeningFcn, ...
                   'gui_OutputFcn',  @referencefig_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before referencefig is made visible.
function referencefig_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to referencefig (see VARARGIN)

% Choose default command line output for referencefig
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes referencefig wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = referencefig_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on button press in refbutton.
function refbutton_Callback(hObject, eventdata, handles)
% hObject    handle to refbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
x = get(handles.figure1, 'UserData');
x.reference();


% --- Executes when user attempts to close figure1.
function figure1_CloseRequestFcn(hObject, eventdata, handles)
% hObject    handle to figure1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: delete(hObject) closes the figure
set(hObject, 'Visible', 'off');


% --- Executes on button press in darkbutton.
function darkbutton_Callback(hObject, eventdata, handles)
% hObject    handle to darkbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
x = get(handles.figure1, 'UserData');
x.dark();
